==> magento-module-adobe-io-events-0.2.0.zip: Model/AdobeIOConfigurationProvider.php <==
<?php

namespace Magento\AdobeIoEvents\Model;

use Magento\AdobeIoEvents\Model\Data\AdobeConsoleConfiguration\AdobeConsoleConfiguration;
use Magento\AdobeIoEvents\Model\Data\AdobeConsoleConfiguration\ConfigurationFactory;
use Magento\AdobeIoEvents\Model\Data\EventProvider;
use Magento\AdobeIoEvents\Model\Data\EventProviderFactory;
use Magento\AdobeIoEvents\Model\Data\PrivateKey;
use Magento\AdobeIoEvents\Model\Data\PrivateKeyFactory;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\Config\Storage\WriterInterface;
use Magento\Framework\Exception\NotFoundException;
use Magento\Framework\Phrase;
use Magento\Framework\Serialize\Serializer\Json;

class AdobeIOConfigurationProvider
{
    private const XML_PATH_ADOBE_IO_EVENT_PROVIDER_ID = "adobe_io_events/integration/provider_id";
    private const XML_PATH_ADOBE_IO_EVENT_INSTANCE_ID = "adobe_io_events/integration/instance_id";
    private const XML_PATH_ADOBE_IO_SERVICE_ACCOUNT_PRIVATE_KEY = "adobe_io_events/integration/private_key";
    private const XML_PATH_ADOBE_IO_EVENT_CONSOLE_CONFIGURATION = "adobe_io_events/integration/workspace_configuration";

    /**
     * @var EventProviderFactory
     */
    private EventProviderFactory $eventProviderFactory;

    /**
     * @var Json
     */
    private Json $json;

    /**
     * @var ConfigurationFactory
     */
    private ConfigurationFactory $configurationFactory;

    /**
     * @var PrivateKeyFactory
     */
    private PrivateKeyFactory $privateKeyFactory;

    /**
     * @var ScopeConfigInterface
     */
    private ScopeConfigInterface $scopeConfig;

    /**
     * @var WriterInterface
     */
    private WriterInterface $writer;

    /**
     * @param EventProviderFactory $eventProviderFactory
     * @param Json $json
     * @param ConfigurationFactory $configurationFactory
     * @param PrivateKeyFactory $privateKeyFactory
     * @param ScopeConfigInterface $scopeConfig
     * @param WriterInterface $writer
     */
    public function __construct(
        EventProviderFactory $eventProviderFactory,
        Json $json,
        ConfigurationFactory $configurationFactory,
        PrivateKeyFactory $privateKeyFactory,
        ScopeConfigInterface $scopeConfig,
        WriterInterface $writer
    ) {
        $this->eventProviderFactory = $eventProviderFactory;
        $this->json = $json;
        $this->configurationFactory = $configurationFactory;
        $this->privateKeyFactory = $privateKeyFactory;
        $this->scopeConfig = $scopeConfig;
        $this->writer = $writer;
    }

    /**
     * Retrieve Instance ID
     *
     * @return string
     * @throws NotFoundException
     */
    public function retrieveInstanceId(): string
    {
        $instanceId = $this->scopeConfig->getValue(
            self::XML_PATH_ADOBE_IO_EVENT_INSTANCE_ID,
            ScopeConfigInterface::SCOPE_TYPE_DEFAULT
        );

        if (is_array($instanceId) || !$instanceId) {
            throw new NotFoundException(new Phrase("Instance ID not found in configuration"));
        }

        return $instanceId;
    }

    /**
     * Retrieve Event Provider ID
     *
     * @return EventProvider|null
     */
    public function retrieveProvider(): ?EventProvider
    {
        $providerId = $this->scopeConfig->getValue(
            self::XML_PATH_ADOBE_IO_EVENT_PROVIDER_ID,
            ScopeConfigInterface::SCOPE_TYPE_DEFAULT
        );

        if (is_array($providerId) || !$providerId) {
            return null;
        }

        return $this->eventProviderFactory->create(['data' => ['id' => $providerId]]);
    }

    /**
     * @return PrivateKey
     * @throws NotFoundException
     */
    public function getPrivateKey(): PrivateKey
    {
        $privateKeyData = $this->scopeConfig->getValue(
            self::XML_PATH_ADOBE_IO_SERVICE_ACCOUNT_PRIVATE_KEY,
            ScopeConfigInterface::SCOPE_TYPE_DEFAULT
        );

        if (is_array($privateKeyData) || !$privateKeyData) {
            throw new NotFoundException(new Phrase("Private Key not found in configuration"));
        }

        $privateKey = $this->privateKeyFactory->create();
        $privateKey->setData($privateKeyData);

        return $privateKey;
    }

    /**
     * @return AdobeConsoleConfiguration
     * @throws NotFoundException
     */
    public function getConfiguration(): AdobeConsoleConfiguration
    {
        $configuration = $this->scopeConfig->getValue(
            self::XML_PATH_ADOBE_IO_EVENT_CONSOLE_CONFIGURATION,
            ScopeConfigInterface::SCOPE_TYPE_DEFAULT
        );

        if (is_array($configuration) || !$configuration) {
            throw new NotFoundException(new Phrase("Workspace Configuration not found in configuration"));
        }

        $data = $this->json->unserialize($configuration);
        return $this->configurationFactory->create($data);
    }

    /**
     * @param EventProvider $eventProvider
     * @return void
     */
    public function saveProvider(EventProvider $eventProvider) {
        $this->writer->save(
            self::XML_PATH_ADOBE_IO_EVENT_PROVIDER_ID,
            $eventProvider->getId()
        );
    }
}

==> magento-module-adobe-io-events-0.2.1.zip: Model/AdobeIOConfigurationProvider.php <==
<?php

namespace Magento\AdobeIoEvents\Model;

use Magento\AdobeIoEvents\Model\Data\AdobeConsoleConfiguration\AdobeConsoleConfiguration;
use Magento\AdobeIoEvents\Model\Data\AdobeConsoleConfiguration\ConfigurationFactory;
use Magento\AdobeIoEvents\Model\Data\EventProvider;
use Magento\AdobeIoEvents\Model\Data\EventProviderFactory;
use Magento\AdobeIoEvents\Model\Data\PrivateKey;
use Magento\AdobeIoEvents\Model\Data\PrivateKeyFactory;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\Config\Storage\WriterInterface;
use Magento\Framework\Exception\NotFoundException;
use Magento\Framework\Phrase;
use Magento\Framework\Serialize\Serializer\Json;

class AdobeIOConfigurationProvider
{
    private const XML_PATH_ADOBE_IO_EVENT_PROVIDER_ID = "adobe_io_events/integration/provider_id";
    private const XML_PATH_ADOBE_IO_EVENT_INSTANCE_ID = "adobe_io_events/integration/instance_id";
    private const XML_PATH_ADOBE_IO_SERVICE_ACCOUNT_PRIVATE_KEY = "adobe_io_events/integration/private_key";
    private const XML_PATH_ADOBE_IO_EVENT_CONSOLE_CONFIGURATION = "adobe_io_events/integration/workspace_configuration";
    private const XML_PATH_ADOBE_IO_EVENT_PROVIDER_METADATA = "adobe_io_events/integration/adobe_io_event_provider_metadata";

    /**
     * @var EventProviderFactory
     */
    private EventProviderFactory $eventProviderFactory;

    /**
     * @var Json
     */
    private Json $json;

    /**
     * @var ConfigurationFactory
     */
    private ConfigurationFactory $configurationFactory;

    /**
     * @var PrivateKeyFactory
     */
    private PrivateKeyFactory $privateKeyFactory;

    /**
     * @var ScopeConfigInterface
     */
    private ScopeConfigInterface $scopeConfig;

    /**
     * @var WriterInterface
     */
    private WriterInterface $writer;

    /**
     * @param EventProviderFactory $eventProviderFactory
     * @param Json $json
     * @param ConfigurationFactory $configurationFactory
     * @param PrivateKeyFactory $privateKeyFactory
     * @param ScopeConfigInterface $scopeConfig
     * @param WriterInterface $writer
     */
    public function __construct(
        EventProviderFactory $eventProviderFactory,
        Json $json,
        ConfigurationFactory $configurationFactory,
        PrivateKeyFactory $privateKeyFactory,
        ScopeConfigInterface $scopeConfig,
        WriterInterface $writer
    ) {
        $this->eventProviderFactory = $eventProviderFactory;
        $this->json = $json;
        $this->configurationFactory = $configurationFactory;
        $this->privateKeyFactory = $privateKeyFactory;
        $this->scopeConfig = $scopeConfig;
        $this->writer = $writer;
    }

    /**
     * Retrieve Instance ID
     *
     * @return string
     * @throws NotFoundException
     */
    public function retrieveInstanceId(): string
    {
        $instanceId = $this->scopeConfig->getValue(
            self::XML_PATH_ADOBE_IO_EVENT_INSTANCE_ID,
            ScopeConfigInterface::SCOPE_TYPE_DEFAULT
        );

        if (is_array($instanceId) || !$instanceId) {
            throw new NotFoundException(new Phrase("Instance ID not found in configuration"));
        }

        return $instanceId;
    }

    /**
     * Retrieve Event Provider ID
     *
     * @return EventProvider|null
     */
    public function retrieveProvider(): ?EventProvider
    {
        $providerId = $this->scopeConfig->getValue(
            self::XML_PATH_ADOBE_IO_EVENT_PROVIDER_ID,
            ScopeConfigInterface::SCOPE_TYPE_DEFAULT
        );

        if (is_array($providerId) || !$providerId) {
            return null;
        }

        return $this->eventProviderFactory->create(['data' => ['id' => $providerId]]);
    }

    /**
     * @return PrivateKey
     * @throws NotFoundException
     */
    public function getPrivateKey(): PrivateKey
    {
        $privateKeyData = $this->scopeConfig->getValue(
            self::XML_PATH_ADOBE_IO_SERVICE_ACCOUNT_PRIVATE_KEY,
            ScopeConfigInterface::SCOPE_TYPE_DEFAULT
        );

        if (is_array($privateKeyData) || !$privateKeyData) {
            throw new NotFoundException(new Phrase("Private Key not found in configuration"));
        }

        $privateKey = $this->privateKeyFactory->create();
        $privateKey->setData($privateKeyData);

        return $privateKey;
    }

    /**
     * @return AdobeConsoleConfiguration
     * @throws NotFoundException
     */
    public function getConfiguration(): AdobeConsoleConfiguration
    {
        $configuration = $this->scopeConfig->getValue(
            self::XML_PATH_ADOBE_IO_EVENT_CONSOLE_CONFIGURATION,
            ScopeConfigInterface::SCOPE_TYPE_DEFAULT
        );

        if (is_array($configuration) || !$configuration) {
            throw new NotFoundException(new Phrase("Workspace Configuration not found in configuration"));
        }

        $data = $this->json->unserialize($configuration);
        return $this->configurationFactory->create($data);
    }

    /**
     * @param EventProvider $eventProvider
     * @return void
     */
    public function saveProvider(EventProvider $eventProvider)
    {
        $this->writer->save(
            self::XML_PATH_ADOBE_IO_EVENT_PROVIDER_ID,
            $eventProvider->getId()
        );
    }

    /**
     * @return string
     */
    public function getEventProviderMetadata(): ?string
    {
        $value = $this->scopeConfig->getValue(
            self::XML_PATH_ADOBE_IO_EVENT_PROVIDER_METADATA,
            ScopeConfigInterface::SCOPE_TYPE_DEFAULT
        );

        if (is_array($value) || !$value) {
            return null;
        }

        return $value;
    }
}
